# -*- coding: utf-8 -*-
try:
    from urllib2 import urlopen, Request
except ImportError:
    from urllib.request import urlopen, Request
try:
    from urlparse import urlparse, urljoin
except ImportError:
    from urllib.parse import urlparse, urljoin
import sys, re, time

if sys.version_info < (2, 7) or (sys.version_info >= (3, 0) and sys.version_info < (3, 1)):
    import simplejson as json
    from simplejson import OrderedDict
else:
    import json
    from collections import OrderedDict


def httpget(url):
    request = Request(url)
    request.add_header('User-Agent',
                       'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.142 Safari/537.36')
    try:
        return urlopen(request).read().decode('utf-8')
    except:
        return False


def sports(url):
    content = httpget(url)
    if not content:
        return {'code': 'huarentv 300'}
    content = re.search('var\s+pageInfo\s*=\s*(.*?)\s*;', content)
    if not content:
        return {'code': 'huarentv 301'}
    content = content.group(1)
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except:
        return {'code': 'huarentv 302'}
    try:
        data = data['live_enter']['0']
    except:
        return {'code': 'huarentv 303'}
    items = []
    for e in data:
        title = ''
        if 'time' in e:
            title += time.strftime('%d %H:%M', time.localtime(e['time'])) + ' '
        if 'cate' in e:
            title += e['cate']
        if 'team' in e:
            for e1 in e['team']:
                title += ' ' + e1
        if e['url']:
            items.append({'title': title, 'url': urljoin(url, e['url'])})
    return {'item': items}


def sport(url):
    content = httpget(url)
    if not content:
        return {'code': 'huarentv 310'}
    content = re.search('window.currentPartInfo\s*=\s*(.*?)\s*;', content)
    if not content:
        return {'code': 'huarentv 311'}
    content = content.group(1)
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except:
        return {'code': 'huarentv 312'}
    if 'playUrl' not in data:
        return {'code': 'huarentv 313'}
    return {'url': {'m3u8': data['playUrl']}}


def category(url, cat, page=1):
    if cat == 'movie':
        c = 1
    elif cat == 'tvdrama':
        c = 2
    elif cat == 'show':
        c = 3
    elif cat == 'anime':
        c = 87
    elif cat == 'child':
        c = 101
    elif cat == 'documentary':
        c = 81
    else:
        c = -1
    url1 = 'http://www.wekan.tv/index.php/video?sort=%%7B%%22click15%%22%%3A-1%%7D&where=%%7B%%22channel%%22%%3A%d%%7D&page=%d&pagesize=30' % (
        c, page)
    content = httpget(url1)
    if not content:
        return {'code': 'huarentv 500'}
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except:
        return {'code': 'huarentv 501'}
    items = []
    if 'data' not in data:
        return {'code': 'huarentv 502'}
    if 'list' not in data['data']:
        return {'code': 'huarentv 503'}
    for e in data['data']['list']:
        items.append({'title': e['title'], 'url': urljoin(url, e['url'])})
    items.append({'title': 'Next Page', 'url': url, 'page': page + 1})
    return {'item': items}


def show(url):
    o = urlparse(url)
    p = o.path.split('/')
    url = 'http://www.wekan.tv/index.php/video/part?tvid=%s' % p[-1]
    content = httpget(url)
    if not content:
        return {'code': 'huarentv 400'}
    try:
        data = json.loads(content, object_pairs_hook=OrderedDict)
    except:
        return {'code': 'huarentv 401'}
    items = []
    if 'data' not in data:
        return {'code': 'huarentv 402'}
    if 'partList' not in data['data']:
        return {'code': 'huarentv 403'}
    for e in data['data']['partList']:
        items.append({'title': e['part_title'], 'url': urljoin(url, e['url'])})
    return {'item': items}
